[jboss-cvs] JBossAS SVN: r63830 - in branches/JBPAPP_4_2_0_GA_CP: console/src/resources/webconsole.war/WEB-INF and 10 other directories.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Wed Jul 4 17:34:47 EDT 2007


Author: dbhole
Date: 2007-07-04 17:34:47 -0400 (Wed, 04 Jul 2007)
New Revision: 63830

Modified:
   branches/JBPAPP_4_2_0_GA_CP/build/build-thirdparty.xml
   branches/JBPAPP_4_2_0_GA_CP/build/build.xml
   branches/JBPAPP_4_2_0_GA_CP/console/src/resources/webconsole.war/WEB-INF/classes/web-console-users.properties
   branches/JBPAPP_4_2_0_GA_CP/console/src/resources/webconsole.war/WEB-INF/jboss-web.xml
   branches/JBPAPP_4_2_0_GA_CP/console/src/resources/webconsole.war/WEB-INF/web.xml
   branches/JBPAPP_4_2_0_GA_CP/server/src/bin/jboss_init_hpux.sh
   branches/JBPAPP_4_2_0_GA_CP/server/src/bin/jboss_init_redhat.sh
   branches/JBPAPP_4_2_0_GA_CP/server/src/bin/jboss_init_suse.sh
   branches/JBPAPP_4_2_0_GA_CP/server/src/etc/conf/default/props/jmx-console-users.properties
   branches/JBPAPP_4_2_0_GA_CP/server/src/resources/jmx-invoker-adaptor/META-INF/jboss-service.xml
   branches/JBPAPP_4_2_0_GA_CP/system/src/bin/run.bat
   branches/JBPAPP_4_2_0_GA_CP/system/src/bin/run.sh
   branches/JBPAPP_4_2_0_GA_CP/system/src/main/org/jboss/system/server/ServerConfig.java
   branches/JBPAPP_4_2_0_GA_CP/varia/src/resources/jmx/jmx-console-web.xml
   branches/JBPAPP_4_2_0_GA_CP/varia/src/resources/jmx/web-inf/jboss-web.xml
   branches/JBPAPP_4_2_0_GA_CP/varia/src/resources/services/invoker/http/web.xml
   branches/JBPAPP_4_2_0_GA_CP/varia/src/resources/services/invoker/httpha/web.xml
Log:


FIX: JBPAPP-242

Checking in patches added during rpmbuild (effectively making the tip=GA + rpm patches)

Patches/changes are:
build-production-config.patch - Create a production config during build

read-local-config-first.patch - Read server/$config/run.conf (if it exists)
                                instead of bin/run.conf

set-default-servername.patch  - Change default startup server to be production

enableauth.patch              - Enable authentication for JMX/Web console, and 
                                jmx/rmi/http invoker

add-serverswitch-to-run-bat.patch - Set -server for all JVM's instead of just
                                    Hotspot

usebrewjbossts.patch          - Switch to use a -brew version of jbossts




Modified: branches/JBPAPP_4_2_0_GA_CP/build/build-thirdparty.xml
===================================================================
--- branches/JBPAPP_4_2_0_GA_CP/build/build-thirdparty.xml	2007-07-04 18:42:04 UTC (rev 63829)
+++ branches/JBPAPP_4_2_0_GA_CP/build/build-thirdparty.xml	2007-07-04 21:34:47 UTC (rev 63830)
@@ -84,7 +84,7 @@
     <componentref name="jboss/common" version="1.2.0.GA-brew"/>
     <componentref name="jboss/dom4j-jarjar" version="1.6.1"/>
     <componentref name="jboss/jaxr" version="1.2.0.GA"/>
-    <componentref name="jboss/jbossts14" version="4.2.3.SP5"/>
+    <componentref name="jboss/jbossts14" version="4.2.3.SP5-brew"/>
     <componentref name="jboss/jbossws-jboss42" version="1.2.1.GA"/>
     <componentref name="jboss/jbossxb" version="1.0.0.GA-brew"/>
     <componentref name="jboss/microcontainer" version="1.0.2"/>

Modified: branches/JBPAPP_4_2_0_GA_CP/build/build.xml
===================================================================
--- branches/JBPAPP_4_2_0_GA_CP/build/build.xml	2007-07-04 18:42:04 UTC (rev 63829)
+++ branches/JBPAPP_4_2_0_GA_CP/build/build.xml	2007-07-04 21:34:47 UTC (rev 63830)
@@ -247,6 +247,11 @@
     <property name="install.all.conf" value="${install.all}/conf"/>
     <property name="install.all.deploy.hasingleton" value="${install.all}/deploy-hasingleton"/>
 
+    <property name="install.production" value="${install.server}/production"/>
+    <property name="install.production.lib" value="${install.production}/lib"/>
+    <property name="install.production.deploy" value="${install.production}/deploy"/>
+    <property name="install.production.conf" value="${install.production}/conf"/>
+
     <property name="install.default" value="${install.server}/default"/>
     <property name="install.default.lib" value="${install.default}/lib"/>
     <property name="install.default.deploy" value="${install.default}/deploy"/>
@@ -607,16 +612,39 @@
    </target>
 
 
-  <!-- Partition the default single configuration build into a minimal,
-  default and all configs with a minimal set of jars in the root lib dir.
+  <!-- Partition the default single configuration build into a all, production,
+  default and minimal configs with a minimal set of jars in the root lib dir.
   -->
   <target name="partition-build" depends="init">
+    <antcall target="partition-production"/>
+    <antcall target="makeProductionConfigChanges"/>
     <antcall target="partition-default"/>
     <antcall target="partition-minimal"/>
     <antcall target="jboss-all-client"/>
     <!--<antcall target="setup-ejb3-dist"/>-->
   </target>
 
+  <target name="partition-production"
+    if="build.production" depends="check.production"
+    description="A configuration tailored for production environments">
+    <!-- Copy server/all to server/production and then customize the settings
+    to values appropriate to production runs -->
+    <copy todir="${install.production}">
+      <fileset dir="${install.all}">
+      </fileset>
+    </copy>
+
+    <!-- The customizationd for "production" runs go here -->
+
+    <!-- JAVA_OPTS="-Xms512m -Xmx1024m -XX:PermSize=256m -XX:MaxPermSize=512" -->
+    <copy tofile="${install.production}/run.conf"
+      file="${install.bin}/run.conf" overwrite="true"/>
+    <replace file="${install.production}/run.conf" 
+      token="Xms128m" value="Xms1503m"/>
+    <replace file="${install.production}/run.conf" 
+      token="Xmx512m" value="Xmx1503m"/>
+  </target>
+
   <target name="partition-default"
     description="The legacy jboss base j2ee 1.4 compatible configuration">
     <!-- Copy server/all to server/default and then remove the services and
@@ -825,6 +853,376 @@
     </condition>
   </target>
 
+  <!-- Modify run.sh for production config -->
+  <target name="makeProductionConfigChanges" 
+          if="build.production"
+          depends="partition-production">
+
+  <!-- Set all JVMs except darwin to use -server -->
+
+        <replace file="${install.bin}/run.sh"
+                 summary="true">
+
+            <replacetoken><![CDATA[
+# If -server not set in JAVA_OPTS, set it, if supported
+SERVER_SET=`echo $JAVA_OPTS | $GREP "\-server"`
+if [ "x$SERVER_SET" = "x" ]; then
+
+    # Check for SUN(tm) JVM w/ HotSpot support
+    if [ "x$HAS_HOTSPOT" = "x" ]; then
+	HAS_HOTSPOT=`"$JAVA" -version 2>&1 | $GREP -i HotSpot`
+    fi
+
+    # Enable -server if we have Hotspot, unless we can't
+    if [ "x$HAS_HOTSPOT" != "x" ]; then
+	# MacOS does not support -server flag
+	if [ "$darwin" != "true" ]; then
+	    JAVA_OPTS="-server $JAVA_OPTS"
+	fi
+    fi
+fi
+]]></replacetoken>
+
+            <replacevalue><![CDATA[
+# If -server not set in JAVA_OPTS, set it, if supported
+SERVER_SET=`echo $JAVA_OPTS | $GREP "\-server"`
+if [ "x$SERVER_SET" = "x" ]; then
+
+    # Check for SUN(tm) JVM w/ HotSpot support
+    if [ "x$HAS_HOTSPOT" = "x" ]; then
+	HAS_HOTSPOT=`"$JAVA" -version 2>&1 | $GREP -i HotSpot`
+    fi
+
+    # Enable -server if we have Hotspot, unless we can't
+	# MacOS does not support -server flag
+	if [ "$darwin" != "true" ]; then
+	    JAVA_OPTS="-server $JAVA_OPTS"
+	fi
+fi
+]]></replacevalue>
+
+        </replace>
+
+  <!-- Uncomment the configuration to make the key generation cluster safe -->
+
+        <replace file="${install.production}/deploy/uuid-key-generator.sar/META-INF/jboss-service.xml"
+                 summary="true">
+
+            <replacetoken><![CDATA[
+     <!-- Uncomment to make it cluster-safe: Select current Hi value query (FOR UPDATE is recommended)
+     <attribute name="SelectHiSql">
+        select HIGHVALUES from HILOSEQUENCES where SEQUENCENAME='general' FOR UPDATE
+     </attribute>                                                  
+     -->
+]]></replacetoken>
+
+            <replacevalue><![CDATA[
+     <!-- Uncomment to make it cluster-safe: Select current Hi value query (FOR UPDATE is recommended) -->
+     <attribute name="SelectHiSql">
+        select HIGHVALUES from HILOSEQUENCES where SEQUENCENAME='general' FOR UPDATE
+     </attribute> 
+]]></replacevalue>
+
+        </replace>
+
+  <!-- Only the customers explicit production queues should be configured in the mq destinations file  -->
+
+        <replace file="${install.production}/deploy-hasingleton/jms/jbossmq-destinations-service.xml"
+                 summary="true">
+
+            <replacetoken><![CDATA[
+<server>
+  <!-- Destination without a configured SecurityManager or without a 
+       a SecurityConf will default to role guest with read=true, write=true,
+       create=false.
+  -->
+]]></replacetoken>
+
+            <replacevalue><![CDATA[
+<server>
+  <!-- Destination without a configured SecurityManager or without a 
+       a SecurityConf will default to role guest with read=true, write=true,
+       create=false.
+]]></replacevalue>
+
+        </replace>
+
+        <replace file="${install.production}/deploy-hasingleton/jms/jbossmq-destinations-service.xml"
+                 summary="true">
+
+            <replacetoken><![CDATA[
+</server>
+]]></replacetoken>
+
+            <replacevalue><![CDATA[
+-->
+</server>
+]]></replacevalue>
+
+        </replace>
+
+  <!-- Reduce log verbosity -->
+
+        <replace file="${install.production.conf}/jboss-log4j.xml"
+                 summary="true">
+
+            <replacetoken><![CDATA[
+   <!-- ============================== -->
+   <!-- Append messages to the console -->
+   <!-- ============================== -->
+
+   <appender name="CONSOLE" class="org.apache.log4j.ConsoleAppender">
+      <errorHandler class="org.jboss.logging.util.OnlyOnceErrorHandler"/>
+      <param name="Target" value="System.out"/>
+      <param name="Threshold" value="INFO"/>
+
+      <layout class="org.apache.log4j.PatternLayout">
+         <!-- The default pattern: Date Priority [Category] Message\n -->
+         <param name="ConversionPattern" value="%d{ABSOLUTE} %-5p [%c{1}] %m%n"/>
+      </layout>
+   </appender>
+]]></replacetoken>
+
+            <replacevalue><![CDATA[
+   <!-- ============================== -->
+   <!-- Append messages to the console -->
+   <!-- ============================== -->
+   <!--
+   <appender name="CONSOLE" class="org.apache.log4j.ConsoleAppender">
+      <errorHandler class="org.jboss.logging.util.OnlyOnceErrorHandler"/>
+      <param name="Target" value="System.out"/>
+      <param name="Threshold" value="INFO"/>
+
+      <layout class="org.apache.log4j.PatternLayout">
+         <param name="ConversionPattern" value="%d{ABSOLUTE} %-5p [%c{1}] %m%n"/>
+      </layout>
+   </appender>
+   -->
+]]></replacevalue>
+
+        </replace>
+
+        <replace file="${install.production.conf}/jboss-log4j.xml"
+                 summary="true">
+
+            <replacetoken><![CDATA[
+   <!-- Buffer events and log them asynchronously
+   <appender name="ASYNC" class="org.apache.log4j.AsyncAppender">
+     <errorHandler class="org.jboss.logging.util.OnlyOnceErrorHandler"/>
+     <appender-ref ref="FILE"/>
+     <appender-ref ref="CONSOLE"/>
+     <appender-ref ref="SMTP"/>
+   </appender>
+   -->
+]]></replacetoken>
+
+            <replacevalue><![CDATA[
+   <!-- Buffer events and log them asynchronously -->
+   <appender name="ASYNC" class="org.apache.log4j.AsyncAppender">
+     <errorHandler class="org.jboss.logging.util.OnlyOnceErrorHandler"/>
+     <appender-ref ref="FILE"/>
+     <!--
+     <appender-ref ref="CONSOLE"/>
+     <appender-ref ref="SMTP"/>
+     -->
+   </appender>
+]]></replacevalue>
+
+        </replace>
+
+        <replace file="${install.production.conf}/jboss-log4j.xml"
+                 summary="true">
+
+            <replacetoken><![CDATA[
+   <!-- Limit the org.apache category to INFO as its DEBUG is verbose -->
+   <category name="org.apache">
+      <priority value="INFO"/>
+   </category>
+
+   <!-- Limit the org.jboss.serial (jboss-serialization) to INFO as its DEBUG is verbose -->
+   <category name="org.jboss.serial">
+      <priority value="INFO"/>
+   </category>
+]]></replacetoken>
+
+            <replacevalue><![CDATA[
+   <!-- Limit the org.apache category to INFO as its DEBUG is verbose -->
+   <category name="org.apache">
+      <priority value="WARN"/>
+   </category>
+
+   <!-- Limit the org.jboss.serial (jboss-serialization) to INFO as its DEBUG is verbose -->
+   <category name="org.jboss.serial">
+      <priority value="WARN"/>
+   </category>
+]]></replacevalue>
+
+        </replace>
+
+        <replace file="${install.production.conf}/jboss-log4j.xml"
+                 summary="true">
+
+            <replacetoken><![CDATA[
+   <!-- Limit the JSR77 categories -->
+   <category name="org.jboss.management">
+      <priority value="INFO"/>
+   </category>
+]]></replacetoken>
+
+            <replacevalue><![CDATA[
+   <!-- Limit the JSR77 categories -->
+   <category name="org.jboss.management">
+      <priority value="WARN"/>
+   </category>
+
+   <!-- Limit seam logging -->
+   <category name="org.jboss.seam">
+      <priority value="WARN"/>
+   </category> 
+]]></replacevalue>
+
+        </replace>
+
+        <replace file="${install.production.conf}/jboss-log4j.xml"
+                 summary="true">
+
+            <replacetoken><![CDATA[
+   <root>
+      <appender-ref ref="CONSOLE"/>
+      <appender-ref ref="FILE"/>
+   </root>
+
+]]></replacetoken>
+
+            <replacevalue><![CDATA[
+   <root>
+      <!-- <appender-ref ref="CONSOLE"/> -->
+      <appender-ref ref="ASYNC"/>
+   </root>
+]]></replacevalue>
+
+        </replace>
+
+        <replace file="${install.production.conf}/jboss-log4j.xml"
+                 summary="true">
+
+            <replacetoken><![CDATA[
+   <!-- Clustering logging -->
+   <!-- Uncomment the following to redirect the org.jgroups and
+      org.jboss.ha categories to a cluster.log file.
+
+   <appender name="CLUSTER" class="org.jboss.logging.appender.RollingFileAppender">
+     <errorHandler class="org.jboss.logging.util.OnlyOnceErrorHandler"/>
+     <param name="File" value="${jboss.server.log.dir}/cluster.log"/>
+     <param name="Append" value="false"/>
+     <param name="MaxFileSize" value="500KB"/>
+     <param name="MaxBackupIndex" value="1"/>
+
+     <layout class="org.apache.log4j.PatternLayout">
+       <param name="ConversionPattern" value="%d %-5p [%c] %m%n"/>
+     </layout>
+   </appender>
+   <category name="org.jgroups">
+     <priority value="DEBUG" />
+     <appender-ref ref="CLUSTER"/>
+   </category>
+   <category name="org.jboss.ha">
+     <priority value="DEBUG" />
+     <appender-ref ref="CLUSTER"/>
+   </category>
+   -->
+]]></replacetoken>
+
+            <replacevalue><![CDATA[
+]]></replacevalue>
+
+        </replace>
+
+        <replace file="${install.production.conf}/jboss-log4j.xml"
+                 summary="true">
+
+            <replacetoken><![CDATA[
+   <!-- ================ -->
+   <!-- Limit categories -->
+   <!-- ================ -->
+]]></replacetoken>
+
+            <replacevalue><![CDATA[
+   <!-- Clustering logging -->
+   <!-- Uncomment the following to redirect the org.jgroups and
+      org.jboss.ha categories to a cluster.log file. -->
+   <!--
+   <appender name="CLUSTER" class="org.jboss.logging.appender.RollingFileAppender">
+     <errorHandler class="org.jboss.logging.util.OnlyOnceErrorHandler"/>
+     <param name="File" value="${jboss.server.log.dir}/cluster.log"/>
+     <param name="Append" value="false"/>
+     <param name="MaxFileSize" value="500KB"/>
+     <param name="MaxBackupIndex" value="1"/>
+
+     <layout class="org.apache.log4j.PatternLayout">
+       <param name="ConversionPattern" value="%d %-5p [%c] %m%n"/>
+     </layout>
+   </appender>
+   -->
+
+   <!-- ================ -->
+   <!-- Limit categories -->
+   <!-- ================ -->
+
+   <category name="org.jboss.ha">
+     <priority value="INFO" />
+   </category>
+]]></replacevalue>
+
+        </replace>
+
+  <!-- Increase time between scans for hot deploy -->
+
+        <replace file="${install.production.conf}/jboss-minimal.xml"
+                 summary="true">
+
+            <replacetoken><![CDATA[
+      <attribute name="ScanPeriod">5000</attribute>
+]]></replacetoken>
+
+            <replacevalue><![CDATA[
+      <attribute name="ScanPeriod">60000</attribute>
+]]></replacevalue>
+
+        </replace>
+
+        <replace file="${install.production.conf}/jboss-service.xml"
+                 summary="true">
+
+            <replacetoken><![CDATA[
+      <attribute name="ScanPeriod">5000</attribute>
+]]></replacetoken>
+
+            <replacevalue><![CDATA[
+      <attribute name="ScanPeriod">60000</attribute>
+]]></replacevalue>
+
+        </replace>
+
+  <!-- Disable connection close debug monitoring -->
+
+        <replace file="${install.production}/deploy/jbossjca-service.xml"
+                 summary="true">
+
+            <replacetoken><![CDATA[
+    <!-- Enable connection close debug monitoring -->
+    <attribute name="Debug">true</attribute>
+]]></replacetoken>
+
+            <replacevalue><![CDATA[
+    <!-- Enable connection close debug monitoring -->
+    <attribute name="Debug">false</attribute>
+]]></replacevalue>
+
+        </replace>
+
+  </target>
+
   <!-- set proxy settings -->
   <condition property="hasproxyauth">
         <and>
@@ -853,4 +1251,11 @@
     <setproxy proxyhost="${proxy.host}" proxyport="${proxy.port}" proxyuser="${proxy.username}" proxypassword="${proxy.password}"/>
   </target>
 
+  <!-- check if the the user wants a production config -->
+  <target name="check.production">
+    <condition property="build.production">
+      <isset property="build.production"/>
+    </condition>
+  </target>
+
 </project>

Modified: branches/JBPAPP_4_2_0_GA_CP/console/src/resources/webconsole.war/WEB-INF/classes/web-console-users.properties
===================================================================
--- branches/JBPAPP_4_2_0_GA_CP/console/src/resources/webconsole.war/WEB-INF/classes/web-console-users.properties	2007-07-04 18:42:04 UTC (rev 63829)
+++ branches/JBPAPP_4_2_0_GA_CP/console/src/resources/webconsole.war/WEB-INF/classes/web-console-users.properties	2007-07-04 21:34:47 UTC (rev 63830)
@@ -1,2 +1,2 @@
 # A sample users.properties file for use with the UsersRolesLoginModule
-admin=admin
+#admin=admin

Modified: branches/JBPAPP_4_2_0_GA_CP/console/src/resources/webconsole.war/WEB-INF/jboss-web.xml
===================================================================
--- branches/JBPAPP_4_2_0_GA_CP/console/src/resources/webconsole.war/WEB-INF/jboss-web.xml	2007-07-04 18:42:04 UTC (rev 63829)
+++ branches/JBPAPP_4_2_0_GA_CP/console/src/resources/webconsole.war/WEB-INF/jboss-web.xml	2007-07-04 21:34:47 UTC (rev 63830)
@@ -8,9 +8,8 @@
 
    <!-- Uncomment the security-domain to enable security. You will
    need to edit the htmladaptor login configuration to setup the
-   login modules used to authentication users.
+   login modules used to authentication users. -->
    <security-domain>java:/jaas/web-console</security-domain>
-   -->
 
    <!-- The war depends on the -->
    <depends>jboss.admin:service=PluginManager</depends>

Modified: branches/JBPAPP_4_2_0_GA_CP/console/src/resources/webconsole.war/WEB-INF/web.xml
===================================================================
--- branches/JBPAPP_4_2_0_GA_CP/console/src/resources/webconsole.war/WEB-INF/web.xml	2007-07-04 18:42:04 UTC (rev 63829)
+++ branches/JBPAPP_4_2_0_GA_CP/console/src/resources/webconsole.war/WEB-INF/web.xml	2007-07-04 21:34:47 UTC (rev 63830)
@@ -338,7 +338,7 @@
    <!-- A security constraint that restricts access to the HTML JMX console
    to users with the role JBossAdmin. Edit the roles to what you want and
    uncomment the WEB-INF/jboss-web.xml/security-domain element to enable
-   secured access to the HTML JMX console.
+   secured access to the HTML JMX console. -->
 
    <security-constraint>
    <web-resource-collection>
@@ -354,7 +354,6 @@
    <role-name>JBossAdmin</role-name>
    </auth-constraint>
    </security-constraint>
-   -->
 
    <login-config>
       <auth-method>BASIC</auth-method>

Modified: branches/JBPAPP_4_2_0_GA_CP/server/src/bin/jboss_init_hpux.sh
===================================================================
--- branches/JBPAPP_4_2_0_GA_CP/server/src/bin/jboss_init_suse.sh	2007-07-04 18:42:04 UTC (rev 63829)
+++ branches/JBPAPP_4_2_0_GA_CP/server/src/bin/jboss_init_suse.sh	2007-07-04 21:34:47 UTC (rev 63830)
@@ -33,7 +33,7 @@
 JBOSSCP=${JBOSSCP:-"$JBOSS_HOME/bin/shutdown.jar:$JBOSS_HOME/client/jnet.jar"}
 
 #define the script to use to start jboss
-JBOSSSH=${JBOSSSH:-"$JBOSS_HOME/bin/run.sh -c default"}
+JBOSSSH=${JBOSSSH:-"$JBOSS_HOME/bin/run.sh -c production"}
 
 # Shell functions sourced from /etc/rc.status:
 #      rc_check         check and set local and overall rc status

Modified: branches/JBPAPP_4_2_0_GA_CP/server/src/etc/conf/default/props/jmx-console-users.properties
===================================================================
--- branches/JBPAPP_4_2_0_GA_CP/server/src/etc/conf/default/props/jmx-console-users.properties	2007-07-04 18:42:04 UTC (rev 63829)
+++ branches/JBPAPP_4_2_0_GA_CP/server/src/etc/conf/default/props/jmx-console-users.properties	2007-07-04 21:34:47 UTC (rev 63830)
@@ -1,2 +1,2 @@
 # A sample users.properties file for use with the UsersRolesLoginModule
-admin=admin
+#admin=admin

Modified: branches/JBPAPP_4_2_0_GA_CP/server/src/resources/jmx-invoker-adaptor/META-INF/jboss-service.xml
===================================================================
--- branches/JBPAPP_4_2_0_GA_CP/server/src/resources/jmx-invoker-adaptor/META-INF/jboss-service.xml	2007-07-04 18:42:04 UTC (rev 63829)
+++ branches/JBPAPP_4_2_0_GA_CP/server/src/resources/jmx-invoker-adaptor/META-INF/jboss-service.xml	2007-07-04 21:34:47 UTC (rev 63830)
@@ -111,10 +111,9 @@
             <return-type>java.lang.Object</return-type>
             <descriptors>
                <interceptors>
-                  <!-- Uncomment to require authenticated users
+                  <!-- Uncomment to require authenticated users -->
                   <interceptor code="org.jboss.jmx.connector.invoker.AuthenticationInterceptor"
                      securityDomain="java:/jaas/jmx-console"/>
-                  -->               
                   <!-- Interceptor that deals with non-serializable results -->
                   <interceptor code="org.jboss.jmx.connector.invoker.SerializableInterceptor"
                      policyClass="StripModelMBeanInfoPolicy"/>

Modified: branches/JBPAPP_4_2_0_GA_CP/system/src/bin/run.bat
===================================================================
--- branches/JBPAPP_4_2_0_GA_CP/system/src/bin/run.bat	2007-07-04 18:42:04 UTC (rev 63829)
+++ branches/JBPAPP_4_2_0_GA_CP/system/src/bin/run.bat	2007-07-04 21:34:47 UTC (rev 63830)
@@ -79,9 +79,8 @@
 rem Setup JBoss specific properties
 set JAVA_OPTS=%JAVA_OPTS% -Dprogram.name=%PROGNAME%
 
-rem Add -server to the JVM options, if supported
-"%JAVA%" -version 2>&1 | findstr /I hotspot > nul
-if not errorlevel == 1 (set JAVA_OPTS=%JAVA_OPTS% -server)
+rem Add -server to the JVM options
+set JAVA_OPTS=%JAVA_OPTS% -server
 
 rem JVM memory allocation pool parameters. Modify as appropriate.
 set JAVA_OPTS=%JAVA_OPTS% -Xms128m -Xmx512m

Modified: branches/JBPAPP_4_2_0_GA_CP/system/src/bin/run.sh
===================================================================
--- branches/JBPAPP_4_2_0_GA_CP/system/src/bin/run.sh	2007-07-04 18:42:04 UTC (rev 63829)
+++ branches/JBPAPP_4_2_0_GA_CP/system/src/bin/run.sh	2007-07-04 21:34:47 UTC (rev 63830)
@@ -11,6 +11,23 @@
 PROGNAME=`basename $0`
 GREP="grep"
 
+# Set conf if specified, else set to default
+JBOSSCONF="production"
+
+arg_count=1
+eval SWITCH=\$$arg_count
+while [ ! -z $SWITCH ]
+do
+
+        if [ "$SWITCH" = "-c" ]; then
+            eval JBOSSCONF=\$`expr $arg_count + 1`
+            break
+        fi
+
+        arg_count=`expr $arg_count + 1`
+        eval SWITCH=\$$arg_count
+done
+
 # Use the maximum available, or set MAX_FD != -1 to use that
 MAX_FD="maximum"
 
@@ -49,7 +66,12 @@
 
 # Read an optional running configuration file
 if [ "x$RUN_CONF" = "x" ]; then
-    RUN_CONF="$DIRNAME/run.conf"
+
+    if [ ! -z "$JBOSSCONF" ] && [ -f "$DIRNAME/../server/$JBOSSCONF/run.conf" ]; then
+        RUN_CONF="$DIRNAME/../server/$JBOSSCONF/run.conf"
+    else
+        RUN_CONF="$DIRNAME/run.conf"
+    fi
 fi
 if [ -r "$RUN_CONF" ]; then
     . "$RUN_CONF"

Modified: branches/JBPAPP_4_2_0_GA_CP/system/src/main/org/jboss/system/server/ServerConfig.java
===================================================================
--- branches/JBPAPP_4_2_0_GA_CP/system/src/main/org/jboss/system/server/ServerConfig.java	2007-07-04 18:42:04 UTC (rev 63829)
+++ branches/JBPAPP_4_2_0_GA_CP/system/src/main/org/jboss/system/server/ServerConfig.java	2007-07-04 21:34:47 UTC (rev 63830)
@@ -295,7 +295,7 @@
    /////////////////////////////////////////////////////////////////////////
 
    /** The default value for {@link #SERVER_NAME}. */
-   String DEFAULT_SERVER_NAME = "default";
+   String DEFAULT_SERVER_NAME = "production";
 
    /** The default value for {@link #EXIT_ON_SHUTDOWN}. */
    boolean DEFAULT_EXIT_ON_SHUTDOWN = true;

Modified: branches/JBPAPP_4_2_0_GA_CP/varia/src/resources/jmx/jmx-console-web.xml
===================================================================
--- branches/JBPAPP_4_2_0_GA_CP/varia/src/resources/jmx/jmx-console-web.xml	2007-07-04 18:42:04 UTC (rev 63829)
+++ branches/JBPAPP_4_2_0_GA_CP/varia/src/resources/jmx/jmx-console-web.xml	2007-07-04 21:34:47 UTC (rev 63830)
@@ -81,7 +81,7 @@
    <!-- A security constraint that restricts access to the HTML JMX console
    to users with the role JBossAdmin. Edit the roles to what you want and
    uncomment the WEB-INF/jboss-web.xml/security-domain element to enable
-   secured access to the HTML JMX console.
+   secured access to the HTML JMX console. -->
    <security-constraint>
      <web-resource-collection>
        <web-resource-name>HtmlAdaptor</web-resource-name>
@@ -96,7 +96,6 @@
        <role-name>JBossAdmin</role-name>
      </auth-constraint>
    </security-constraint>
-   -->
 
    <login-config>
       <auth-method>BASIC</auth-method>

Modified: branches/JBPAPP_4_2_0_GA_CP/varia/src/resources/jmx/web-inf/jboss-web.xml
===================================================================
--- branches/JBPAPP_4_2_0_GA_CP/varia/src/resources/jmx/web-inf/jboss-web.xml	2007-07-04 18:42:04 UTC (rev 63829)
+++ branches/JBPAPP_4_2_0_GA_CP/varia/src/resources/jmx/web-inf/jboss-web.xml	2007-07-04 21:34:47 UTC (rev 63830)
@@ -1,7 +1,6 @@
 <jboss-web>
    <!-- Uncomment the security-domain to enable security. You will
       need to edit the htmladaptor login configuration to setup the
-      login modules used to authentication users.
+      login modules used to authentication users. -->
       <security-domain>java:/jaas/jmx-console</security-domain>
-   -->
 </jboss-web>

Modified: branches/JBPAPP_4_2_0_GA_CP/varia/src/resources/services/invoker/http/web.xml
===================================================================
--- branches/JBPAPP_4_2_0_GA_CP/varia/src/resources/services/invoker/http/web.xml	2007-07-04 18:42:04 UTC (rev 63829)
+++ branches/JBPAPP_4_2_0_GA_CP/varia/src/resources/services/invoker/http/web.xml	2007-07-04 21:34:47 UTC (rev 63830)
@@ -156,6 +156,9 @@
             role HttpInvoker to access the HTTP invoker servlets
          </description>
          <url-pattern>/restricted/*</url-pattern>
+         <url-pattern>/JNDIFactory/*</url-pattern>
+         <url-pattern>/EJBInvokerServlet/*</url-pattern>
+         <url-pattern>/JMXInvokerServlet/*</url-pattern>
          <http-method>GET</http-method>
          <http-method>POST</http-method>
       </web-resource-collection>

Modified: branches/JBPAPP_4_2_0_GA_CP/varia/src/resources/services/invoker/httpha/web.xml
===================================================================
--- branches/JBPAPP_4_2_0_GA_CP/varia/src/resources/services/invoker/httpha/web.xml	2007-07-04 18:42:04 UTC (rev 63829)
+++ branches/JBPAPP_4_2_0_GA_CP/varia/src/resources/services/invoker/httpha/web.xml	2007-07-04 21:34:47 UTC (rev 63830)
@@ -203,6 +203,9 @@
             role HttpInvoker to access the HTTP invoker servlets
          </description>
          <url-pattern>/restricted/*</url-pattern>
+         <url-pattern>/JNDIFactory/*</url-pattern>
+         <url-pattern>/EJBInvokerServlet/*</url-pattern>
+         <url-pattern>/JMXInvokerServlet/*</url-pattern>
          <http-method>GET</http-method>
          <http-method>POST</http-method>
       </web-resource-collection>




More information about the jboss-cvs-commits mailing list
--- branches/JBPAPP_4_2_0_GA_CP/server/src/bin/jboss_init_hpux.sh	2007-07-04 18:42:04 UTC (rev 63829)
+++ branches/JBPAPP_4_2_0_GA_CP/server/src/bin/jboss_init_hpux.sh	2007-07-04 21:34:47 UTC (rev 63830)
@@ -26,14 +26,14 @@
 #############
 #    JBOSS_HOME[0]=/opt/jboss1
 #    JBOSS_USER[0]=jboss1
-#    SERVER_NAME[0]=default
+#    SERVER_NAME[0]=production
 #    JBOSS_START[0]=1
 ##   default console logging (you can also just omit the next line)
 #    JBOSS_CONSOLE[0]=""
 #############
 #    JBOSS_HOME[1]=/opt/jboss2
 #    JBOSS_USER[1]=jboss2
-#    SERVER_NAME[1]=default
+#    SERVER_NAME[1]=production
 #    JBOSS_START[1]=1
 ##   No Console logging
 #    JBOSS_CONSOLE[1]=/dev/null
@@ -55,9 +55,10 @@
 #   The default for the 1st instance is /opt/jboss: JBOSS_HOME[0]=/opt/jboss.
 #   No default for any other instance.
 #
 # SERVER_NAME[i] - server instance name.  Normally "all", "default", or
 #   "minimal". Maps to server instance at $JBOSS_HOME/server/$SERVER_NAME
 #   The default value is "default".
 #
 # JBOSS_START[i] - set to "0" to force JBOSS to not start when this script
 #   is run. Usefull when this script is run automatically at system
@@ -220,7 +221,7 @@
     do
 
       # set defaults for any missing values
-      SERVER_NAME[$i]=${SERVER_NAME[i]:-"default"}
+      SERVER_NAME[$i]=${SERVER_NAME[i]:-"production"}
       JBOSS_USER[$i]=${JBOSS_USER[i]:-"jboss"} 
       JBOSS_CONSOLE[$i]=${JBOSS_CONSOLE[i]:-/var/opt/jboss/${JBOSS_USER[i]}/jboss_${SERVER_NAME[i]}.log}
       JBOSS_START[$i]=${JBOSS_START[i]:-1}
@@ -55,9 +55,10 @@
 #   No default for any other instance.
 #
-# SERVER_NAME[i] - server instance name.  Normally "all", "default", or
-#   "minimal". Maps to server instance at $JBOSS_HOME/server/$SERVER_NAME
-#   The default value is "default".
+# SERVER_NAME[i] - server instance name.  Normally "all", "default", 
+#   "minimal" or "production". Maps to server instance at 
+#   $JBOSS_HOME/server/$SERVER_NAME
+#   The default value is "production".
 #
 # JBOSS_START[i] - set to "0" to force JBOSS to not start when this script

Modified: branches/JBPAPP_4_2_0_GA_CP/server/src/bin/jboss_init_redhat.sh
===================================================================
--- branches/JBPAPP_4_2_0_GA_CP/server/src/bin/jboss_init_redhat.sh	2007-07-04 18:42:04 UTC (rev 63829)
+++ branches/JBPAPP_4_2_0_GA_CP/server/src/bin/jboss_init_redhat.sh	2007-07-04 21:34:47 UTC (rev 63830)
@@ -23,8 +23,8 @@
 #make sure java is in your path
 JAVAPTH=${JAVAPTH:-"/usr/local/jdk/bin"}
 
-#configuration to use, usually one of 'minimal', 'default', 'all'
-JBOSS_CONF=${JBOSS_CONF:-"default"}
+#configuration to use, usually one of 'minimal', 'default', 'all', 'production'
+JBOSS_CONF=${JBOSS_CONF:-"production"}
 
 #if JBOSS_HOST specified, use -b to bind jboss services to that address
 JBOSS_BIND_ADDR=${JBOSS_HOST:+"-b $JBOSS_HOST"}

Modified: branches/JBPAPP_4_2_0_GA_CP/server/src/bin/jboss_init_suse.sh
===================================================================